==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/EXTMENUSHIERARCHYREQUEST_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour EXTMENUSHIERARCHYREQUEST_Type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * <p>
 * <pre>
 * &lt;simpleType name="EXTMENUSHIERARCHYREQUEST_Type">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="All"/>
 *     &lt;enumeration value="ExcludePermissions"/>
 *     &lt;enumeration value="ExcludeTabs"/>
 *     &lt;enumeration value="ExcludePermissionsandTabs"/>
 *     &lt;enumeration value="ExcludeHiddenPermissionsandTabs"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "EXTMENUSHIERARCHYREQUEST_Type")
@XmlEnum
public enum EXTMENUSHIERARCHYREQUEST_Type {

    @XmlEnumValue("All")
    ALL("All"),
    @XmlEnumValue("ExcludePermissions")
    EXCLUDE_PERMISSIONS("ExcludePermissions"),
    @XmlEnumValue("ExcludeTabs")
    EXCLUDE_TABS("ExcludeTabs"),
    @XmlEnumValue("ExcludePermissionsandTabs")
    EXCLUDE_PERMISSIONSAND_TABS("ExcludePermissionsandTabs"),
    @XmlEnumValue("ExcludeHiddenPermissionsandTabs")
    EXCLUDE_HIDDEN_PERMISSIONSAND_TABS("ExcludeHiddenPermissionsandTabs");
    private final String value;

    EXTMENUSHIERARCHYREQUEST_Type(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static EXTMENUSHIERARCHYREQUEST_Type fromValue(String v) {
        for (EXTMENUSHIERARCHYREQUEST_Type c: EXTMENUSHIERARCHYREQUEST_Type.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/EXTMENUSHIERARCHYREQUEST_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for EXTMENUSHIERARCHYREQUEST_Type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="EXTMENUSHIERARCHYREQUEST_Type">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="All"/>
 *     &lt;enumeration value="ExcludePermissions"/>
 *     &lt;enumeration value="ExcludeTabs"/>
 *     &lt;enumeration value="ExcludePermissionsandTabs"/>
 *     &lt;enumeration value="ExcludeHiddenPermissionsandTabs"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "EXTMENUSHIERARCHYREQUEST_Type")
@XmlEnum
public enum EXTMENUSHIERARCHYREQUEST_Type {

    @XmlEnumValue("All")
    ALL("All"),
    @XmlEnumValue("ExcludePermissions")
    EXCLUDE_PERMISSIONS("ExcludePermissions"),
    @XmlEnumValue("ExcludeTabs")
    EXCLUDE_TABS("ExcludeTabs"),
    @XmlEnumValue("ExcludePermissionsandTabs")
    EXCLUDE_PERMISSIONSAND_TABS("ExcludePermissionsandTabs"),
    @XmlEnumValue("ExcludeHiddenPermissionsandTabs")
    EXCLUDE_HIDDEN_PERMISSIONSAND_TABS("ExcludeHiddenPermissionsandTabs");
    private final String value;

    EXTMENUSHIERARCHYREQUEST_Type(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static EXTMENUSHIERARCHYREQUEST_Type fromValue(String v) {
        for (EXTMENUSHIERARCHYREQUEST_Type c: EXTMENUSHIERARCHYREQUEST_Type.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
